@@ -91,11 +91,23 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 		Set<Class< ? >> nmv = new HashSet<>(cim.keySet());
 		nmv.addAll(Arrays.<Class< ? >> asList(String.class, Class.class,
 				Comparable.class, CharSequence.class, Map.Entry.class));
+		// The following classes are only available from Java 12 onwards
+		addClassIfAvailable("java.lang.constant.Constable", nmv);
+		addClassIfAvailable("java.lang.constant.ConstantDesc", nmv);
 
 		INTERFACE_IMPLS = Collections.unmodifiableMap(iim);
 		NO_MAP_VIEW_TYPES = Collections.unmodifiableSet(nmv);
 	}
 
+	private static void addClassIfAvailable(String cls, Collection<Class<?>> collection) {
+	    try {
+	        Class<?> clazz = ConvertingImpl.class.getClassLoader().loadClass(cls);
+	        collection.add(clazz);
+	    } catch (Exception ex) {
+	        // Class not available, to nothing
+	    }
+	}
+
 	private final InternalConverter converter;
 	private volatile Object		object;
 	private volatile Class< ? >	sourceClass;
@@ -265,9 +277,9 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 			return c.convert(entry.getKey()).to(cls);
 		} else if (cls.equals(valueCls)) {
 			return c.convert(entry.getValue()).to(cls);
-		} else if (cls.isAssignableFrom(keyCls)) {
+		} else if (keyCls != null && cls.isAssignableFrom(keyCls)) {
 			return c.convert(entry.getKey()).to(cls);
-		} else if (cls.isAssignableFrom(valueCls)) {
+		} else if (valueCls != null && cls.isAssignableFrom(valueCls)) {
 			return c.convert(entry.getValue()).to(cls);
 		} else if (entry.getKey() instanceof String) {
 			return c.convert(entry.getKey()).to(cls);
@@ -831,7 +843,7 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 					i++;
 					componentType = componentType.getComponentType();
 				}
-				
+
 				if(i == 1) {
 					return Array.newInstance(componentType, 0);
 				} else {
